Index: basecode.h
===================================================================
RCS file: /cvs/kaffe/kaffe/kaffe/kaffevm/jit3/basecode.h,v
retrieving revision 1.6
diff -u -p -r1.6 basecode.h
--- basecode.h	11 Feb 2003 16:54:45 -0000	1.6
+++ basecode.h	12 Mar 2003 09:20:06 -0000
@@ -93,7 +93,12 @@ enum {
 #define	monitor_exit()		mon_exit(xmeth, local(0))
 
 /* -------------------------------------------------------------------- */
-/* Instruction formats */
+/* Instruction formats
+ *
+ * These functions and macros take care of properly creating and initializing
+ * a struct _sequence for the different instructions. There's one function
+ * provided for every possible instruction format. 
+ */
 
 #define	slot_const_const(dst, src, src2, func, t)			\
 	{								\
Index: registers.h
===================================================================
RCS file: /cvs/kaffe/kaffe/kaffe/kaffevm/jit3/registers.h,v
retrieving revision 1.6
diff -u -p -r1.6 registers.h
--- registers.h	27 Dec 2000 06:21:04 -0000	1.6
+++ registers.h	12 Mar 2003 09:20:06 -0000
@@ -27,18 +27,45 @@
 
 /* Information about the state of a particular register. */
 typedef struct _kregs {
-	/* The slot whose value is in this register. */
+	/* The list of slots whose values are in this register. */
 	SlotData*		slot;
+
+        /* current type of the register */
 	uint8			ctype;
+	
+	/* type of the register */
 	uint8			type;
+
+	/* flags of the register */
 	uint8			flags;
+
+	/* the last time this register was assigned to a slot */
 	uint32			used;
+
+	/* id of this register */
 	uint8			regno;
+
+	/* number of slots whose values are in this register */
 	uint8			refs;
 } kregs;
 
+/*
+ * array containing information about all registers of the architecture the
+ * jitter was compiled for.
+ * 
+ * initialized by the REGISTER_SET macro to be defined by the backend.
+ */ 
 extern kregs reginfo[];
+
+/*
+ * number of register assignments done so far.
+ * (FIXME: why is this one exported?)
+ */
 extern int usecnt;
+
+/*
+ * ???
+ */
 extern int enable_readonce;
 
 #define	MAXREG			NR_REGISTERS
Index: seq.h
===================================================================
RCS file: /cvs/kaffe/kaffe/kaffe/kaffevm/jit3/seq.h,v
retrieving revision 1.6
diff -u -p -r1.6 seq.h
--- seq.h	13 Oct 1999 01:23:01 -0000	1.6
+++ seq.h	12 Mar 2003 09:20:06 -0000
@@ -16,10 +16,23 @@ struct _label_;
 
 typedef void (*ifunc)(struct _sequence*);
 
+/* maximum number of arguments for one sequence */
 #define	SEQSLOTS		5
 
+/* 
+ * a struct _sequence is one instruction of the intermediate language of the jitter.
+ *
+ * These intermediate instructions are generated while reading the java bytecode
+ * and are translated into native code afterwards. This translation is done
+ * per basic block rather than per method.
+ */
 typedef struct _sequence {
+	/* the function that is able to emit native code 
+           corresponding to this instruction */
 	ifunc			func;
+
+	/* parameters for this instruction,
+           their meaning depends on the value of func */
 	union {
 		jvalue		value;
 		struct _label_* labconst;
@@ -27,18 +40,47 @@ typedef struct _sequence {
 		struct SlotData** smask;
 		struct SlotData* slot;
 	} u[SEQSLOTS];
+
+	/* type of the instruction, one of the T* constants defined in slots.h 
+           (FIXME: why are they #defined there?) */
 	uint8			type;
+
+	/* true iff generation of native code for this instruction
+           is necessary, otherwise false */
 	uint8			refed;
+
+	/* bitmask of the slots not being accessed after this
+           instruction (FIXME: why is this a 32bit int? It
+           seems to be used only as an index into u) */
 	uint32			lastuse;
+
+	/* pointer to the instruction following this one */
 	struct _sequence*	next;
 } sequence;
 
+/*
+ * resets the pool of sequence objects allocated by the jitter.
+ */
 void initSeq(void);
+
+/*
+ * returns a new sequence object
+ */
 sequence* nextSeq(void);
 
+/*
+ * These track the pool of sequence objects allcoated by the jitter. 
+ * The set of valid sequence objects is the sublist between firstSeq
+ * and currSeq, exclusive.
+ */
 extern sequence*		firstSeq;
 extern sequence*		lastSeq;
 extern sequence*		currSeq;
+
+/*
+ * sequence currently being created (return value of last call to nextSeq).
+ * (FIXME: why is this one necessary?)
+ */
 extern sequence* 		activeSeq;
 
 #define	ALLOCSEQNR		1024
Index: slots.h
===================================================================
RCS file: /cvs/kaffe/kaffe/kaffe/kaffevm/jit3/slots.h,v
retrieving revision 1.3
diff -u -p -r1.3 slots.h
--- slots.h	16 Oct 1999 03:16:26 -0000	1.3
+++ slots.h	12 Mar 2003 09:20:06 -0000
@@ -38,14 +38,40 @@
 #define	SR_START		4
 #define	SR_EXCEPTION		5
 
+/*
+ * used to track a function's locals, arguments and temps.
+ *
+ * A SlotData represents both, a local variable of the execution frame as defined
+ * in the JVM Spec, second edition, 3.6.1 and an entry of the operand stack
+ * as in 3.6.2. As such, longs and doubles occupy two SlotDatas, all other
+ * types only one.
+ */
 struct SlotData {
+        /* index of the register holding the value of this slot */
 	uint16			regno;
+
+        /* stack frame offset of this slot */
 	int			offset;
+
+        /* the last sequence writing this slot */
 	struct _sequence*	wseq;
+	
+	/* the last sequence reading this slot */
 	struct _sequence*	rseq;
+
+	/* slot == slot->rseq->u[slot->rseqslot].slot,
+           however this is expressed in plain english */
 	uint8			rseqslot;
+
+	/* flag indicating how this slot is modified (either rread, rwrite or rnone)
+           (FIXME: are these flags necessary? what about determining
+           them on the fly using rseq and wseq?) */
 	uint8			modified;
+
+	/* pointer to the next slot whose value is stored in the same register */
 	struct SlotData*	rnext;
+
+	/* flag indicating whether this slot contains a global value */
 	int			global;
 };
 typedef struct SlotData SlotData;
@@ -70,13 +96,52 @@ typedef struct SlotInfo SlotInfo;
 
 #define	REGSLOT	SlotData
 
+/*
+ * array containing all slots of the method being translated.
+ */
 extern SlotInfo* basicslots;
+
+/*
+ * same as basicslots ???
+ */
 extern SlotInfo* slotinfo;
+
+/*
+ * array of locals of the method being translated.
+ *
+ * the first localsz entries correspond to the local variables as per vm spec,
+ * the last stacksz entries correspond to the entries of the operand stack
+ *
+ * The bottom of the operand stack is the last entry of this array and it
+ * grows downwards (towards smaller indices).
+ */
 extern SlotInfo* localinfo;
+
+/*
+ * array of temp slots being used by the generated native code.
+ */
 extern SlotInfo* tempinfo;
+
+/*
+ * the slot that contains the stack limit.
+ *
+ * only used when STACK_LIMIT is #defined by the backend. 
+ */
 extern SlotInfo stack_limit[1];
+
+/*
+ * index of first unused element of tempinfo (next available temp slot)
+ */
 extern int tmpslot;
+
+/*
+ * top of the operand stack. localsz <= stackno < localsz+stacksz
+ */
 extern int stackno;
+
+/*
+ * number of elements in basicslots.
+ */
 extern int maxslot;
 
 void initSlots(int);
